==> speclate-cli-14.0.1.tgz: package/lib/generators/app-cache.js <==
'use strict'
var async = require('async')
var moveFile = require('../move-file')
var chalk = require('chalk')

/**
 * Generates an app cache file based on the spec provided.
 */

var fs = require('fs')
var path = require('path')
var files = [
  'CACHE MANIFEST'
]

module.exports = function (spec, speclate, callback) {

  files = files.concat(sortFiles(spec))
  files.push('# v-' + +new Date())
  files.push('NETWORK:', '*')

  var partPath = path.join(process.cwd(), spec.options.outputDir, '/manifest.appcache')

  async.forEach(spec.options.appCacheFiles, function (file, next) {

    moveFile(file, spec.options, function () {
      console.log(chalk.grey('  Moved file', file))
      next()
    })
  })
  console.log(chalk.grey('  written: ', partPath))
  console.log(chalk.green('  ok'))
  fs.writeFile(partPath, files.join('\n'), callback)
}


var sortFiles = function (spec) {
  var files = ['/', '/pages/layout.html'].concat(spec.options.files, spec.options.appCacheFiles)


  Object.keys(spec).forEach(function (page) {
    // no de-duping going on - same page/component could be listed twice.

    if (page === 'options' || page === 'defaultSpec') {
      return
    }
    var pageName = spec[page].page
    var routeName
    if (page === '/') {
      routeName = 'index'
    } else {
      routeName = page.slice(0, -5)
    }
    files.push(page)
    files.push('/pages/' + pageName + '/' + pageName + '.html')

    files.push('/' + routeName + '.json')
    for (var selector in spec[page].spec) {
      var component = spec[page].spec[selector].component
      if (component) {
        files.push('/components/' + component + '/' + component + '.html')
      }
    }
  })

  return files
}

==> speclate-cli-17.0.0.tgz: package/lib/generators/app-cache.js <==
'use strict'
var async = require('async')
var moveFile = require('../move-file')
var log = require('../log')

/**
 * Generates an app cache file based on the spec provided.
 */

var fs = require('fs')
var path = require('path')
var files = [
  'CACHE MANIFEST'
]

module.exports = function (spec, options, callback) {
  files = files.concat(sortFiles(spec, options))
  files.push('# v-' + +new Date())
  files.push('NETWORK:', '*')

  var partPath = path.join(process.cwd(), options.outputDir, '/manifest.appcache')

  async.forEach(options.appCacheFiles, function (file, next) {
    moveFile(file, spec.options, function () {
      log.debug(`Moved file ${file}`)
      next()
    })
  })
  log.debug(`written ${partPath}`)
  log.success('ok')
  fs.writeFile(partPath, files.join('\n'), callback)
}

var sortFiles = function (spec, options) {
  var files = ['/', '/pages/layout.html'].concat(options.files, options.appCacheFiles)

  Object.keys(spec).forEach(function (page) {
    // no de-duping going on - same page/component could be listed twice.

    var pageName = spec[page].page
    var routeName
    if (page === '/') {
      routeName = 'index'
    } else {
      routeName = page.slice(0, -5)
    }
    files.push(page)
    files.push('/pages/' + pageName + '/' + pageName + '.html')

    files.push('/' + routeName + '.json')
    for (var selector in spec[page].spec) {
      var component = spec[page].spec[selector].component
      if (component) {
        files.push('/components/' + component + '/' + component + '.html')
      }
    }
  })

  return files
}
